/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
package org.openmuc.jsml;

import java.util.List;

import org.openmuc.jsml.structures.EMessageBody;
import org.openmuc.jsml.structures.SmlFile;
import org.openmuc.jsml.structures.SmlMessage;
import org.openmuc.jsml.structures.responses.SmlAttentionRes;
import org.openmuc.jsml.structures.responses.SmlGetListRes;
import org.openmuc.jsml.structures.responses.SmlGetProcParameterRes;
import org.openmuc.jsml.structures.responses.SmlGetProfileListRes;
import org.openmuc.jsml.structures.responses.SmlGetProfilePackRes;
import org.openmuc.jsml.structures.responses.SmlPublicCloseRes;
import org.openmuc.jsml.structures.responses.SmlPublicOpenRes;

/**
 * Class to parse a SML_FILE
 */
public class GenericParser {

    private GenericParser() {
        // private constructor to hide the implicit public one, since static methods should be accessed in static way so
        // there is no need of public constructor
    }

    /**
     * Prints the whole SML_File
     * 
     * @param smlFile
     *            the SML file
     */
    public static void printFile(SmlFile smlFile) {

        List<SmlMessage> smlMessages = smlFile.getMessages();

        for (SmlMessage smlMessage : smlMessages) {

            int tag = smlMessage.getMessageBody().getTag().getVal();

            EMessageBody messageBody = EMessageBody.toEnum(tag);

            switch (messageBody) {

            case OPEN_REQUEST:
                parseOpenRequest(smlMessage);
                break;
            case OPEN_RESPONSE:
                parseOpenResponse(smlMessage);
                break;
            case CLOSE_REQUEST:
                parseCloseRequest(smlMessage);
                break;
            case CLOSE_RESPONSE:
                parseCloseResponse(smlMessage);
                break;
            case GET_PROFILE_PACK_REQUEST:
                parseGetProfilePackRequest(smlMessage);
                break;
            case GET_PROFILE_PACK_RESPONSE:
                parseGetProfilePackResponse(smlMessage);
                break;
            case GET_PROFILE_LIST_REQUEST:
                parseGetProfileListRequest(smlMessage);
                break;
            case GET_PROFILE_LIST_RESPONSE:
                parseGetProfileListResponse(smlMessage);
                break;
            case GET_PROC_PARAMETER_REQUEST:
                parseGetProcParameterRequest(smlMessage);
                break;
            case GET_PROC_PARAMETER_RESPONSE:
                parseGetProcParameterResponse(smlMessage);
                break;
            case SET_PROC_PARAMETER_REQUEST:
                parseSetProcParameterRequest(smlMessage);
                break;
            case GET_LIST_REQUEST:
                parseGetListRequest(smlMessage);
                break;
            case GET_LIST_RESPONSE:
                parseGetListResponse(smlMessage);
                break;
            case ATTENTION_RESPONSE:
                parseAttentionResponse(smlMessage);
                break;
            default:
                System.out.println("type not found");
            }
        }
    }

    // ========================= Responses =================================

    private static void parseGetListResponse(SmlMessage smlMessage) {
        System.out.println("Got GetListResponse");
        SmlGetListRes sml_listRes = (SmlGetListRes) smlMessage.getMessageBody().getChoice();

        // System.out.println(sml_listRes.toString());

        // TODO working on indents for better human readability
        System.out.println(sml_listRes.toStringIndent(" "));
    }

    private static void parseAttentionResponse(SmlMessage smlMessage) {
        System.out.println("Got AttentionResponse");
        SmlAttentionRes sml_attentionRes = (SmlAttentionRes) smlMessage.getMessageBody().getChoice();
        System.out.println(sml_attentionRes.toString());
    }

    private static void parseGetProcParameterResponse(SmlMessage smlMessage) {
        System.out.println("Got GetProcParameterResponse");
        SmlGetProcParameterRes sml_getProcParameterRes = (SmlGetProcParameterRes) smlMessage.getMessageBody()
                .getChoice();
        System.out.println(sml_getProcParameterRes.toString());
    }

    private static void parseGetProfileListResponse(SmlMessage smlMessage) {
        System.out.println("Got GetProfileListResponse");
        SmlGetProfileListRes sml_getProfileListRes = (SmlGetProfileListRes) smlMessage.getMessageBody().getChoice();
        System.out.println(sml_getProfileListRes.toString());
    }

    private static void parseOpenResponse(SmlMessage smlMessage) {
        System.out.println("Got OpenResponse");
        SmlPublicOpenRes sml_PublicOpenRes = (SmlPublicOpenRes) smlMessage.getMessageBody().getChoice();
        System.out.println(sml_PublicOpenRes.toString());
    }

    private static void parseCloseResponse(SmlMessage smlMessage) {
        System.out.println("Got CloseResponse");
        SmlPublicCloseRes sml_PublicCloseRes = (SmlPublicCloseRes) smlMessage.getMessageBody().getChoice();
        System.out.println(sml_PublicCloseRes.toString());
    }

    private static void parseGetProfilePackResponse(SmlMessage smlMessage) {
        System.out.println("Got GetProfilePackResponse");
        SmlGetProfilePackRes sml_getProfilePackRes = (SmlGetProfilePackRes) smlMessage.getMessageBody().getChoice();
        System.out.println(sml_getProfilePackRes.toString());
    }

    // ========================= Requests =================================

    private static void parseCloseRequest(SmlMessage smlMessage) {
        System.out.println("Got CloseRequest");
        // TODO further parsing
    }

    private static void parseGetProfileListRequest(SmlMessage smlMessage) {
        System.out.println("Got GetProfileListRequest");
        // TODO further parsing
    }

    private static void parseGetProfilePackRequest(SmlMessage smlMessage) {
        System.out.println("Got GetProfilePackRequest");
        // TODO further parsing
    }

    private static void parseOpenRequest(SmlMessage smlMessage) {
        System.out.println("Got OpenRequest");
        // TODO further parsing
    }

    private static void parseGetProcParameterRequest(SmlMessage smlMessage) {
        System.out.println("Got GetProcParameterRequest");
        // TODO further parsing
    }

    private static void parseSetProcParameterRequest(SmlMessage smlMessage) {
        System.out.println("Got SetProcParameterRequest");
        // TODO further parsing
    }

    private static void parseGetListRequest(SmlMessage smlMessage) {
        System.out.println("Got GetListRequest");
        // TODO further parsing
    }
}
