/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
package org.openmuc.jsml.structures;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

public abstract class ASNObject {

    /**
     * logger for debugging output
     */

    /**
     * true if the Object is Optional
     */
    protected boolean isOptional = false;
    /**
     * true if the Object is selected
     */
    protected boolean isSelected = false;

    /**
     * encodes this object and writes it to the stream os.
     * 
     * @param os
     *            output stream
     * @throws IOException
     *             if something went wrong while writing to the stream
     */
    public abstract void encode(DataOutputStream os) throws IOException;

    /**
     * decodes the data from the InputStream and writes it to an object
     * 
     * @param is
     *            input stream
     * @return true if successfully decoded
     * @throws IOException
     *             if something went wrong while reading from the stream
     */
    public abstract boolean decode(DataInputStream is) throws IOException;

    // /**
    // * prints the content or type of the object to stdout
    // */
    // public abstract void print();

    /**
     * marks this object as optional
     */
    public void setOptional() {
        isOptional = true;
    }

    /**
     * marks this object as selected
     */
    public void setSelected() {
        isSelected = true;
    }

    /**
     * returns if this object is selected
     * 
     * @return boolean
     */
    public boolean isSelected() {
        return isSelected;
    }

    /**
     * returns if this object is optional
     * 
     * @return boolean
     */
    public boolean isOptional() {
        return isOptional;
    }
}
