/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
package org.openmuc.jsml.structures;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.PushbackInputStream;

public abstract class ImplicitChoice extends ASNObject {

    public static final int OCTETSTRING = 0, SML_BOOLEAN = 4, INTEGER = 5, UNSIGNED = 6, TL_FIELD = 8;

    protected ASNObject choice;

    @Override
    public void encode(DataOutputStream os) throws IOException {
        if (isOptional && !isSelected) {
            os.writeByte(0x01);
            return;
        }
        choice.encode(os);
    }

    @Override
    public boolean decode(DataInputStream is) throws IOException {
        PushbackInputStream ispushback = new PushbackInputStream(is);
        DataInputStream is2 = new DataInputStream(ispushback);

        byte tlFieldChoice = (byte) ispushback.read();
        if (isOptional && (tlFieldChoice == 0x01)) {
            isSelected = false;
            return true;
        }

        // read type-part of tlFieldChoice
        switch ((tlFieldChoice & 0xF0) >> 4) {
        case OCTETSTRING:
            choice = new OctetString();
            break;

        case SML_BOOLEAN:
            choice = new SmlBoolean();
            break;

        case INTEGER:
            // read length-part of tlFieldChoice
            switch (tlFieldChoice & 0x0F) {
            case 2:
                choice = new Integer8();
                break;
            case 3:
                choice = new Integer16();
                break;
            case 4:
            case 5:
                choice = new Integer32();
                break;
            case 6:
            case 7:
            case 8:
            case 9:
                choice = new Integer64();
                break;
            default:
                return false;
            }

            break;

        case UNSIGNED:
            // read length-part of tlFieldChoice
            switch (tlFieldChoice & 0x0F) {
            case 2:
                choice = new Unsigned8();
                break;
            case 3:
                choice = new Unsigned16();
                break;
            case 4:
            case 5:
                choice = new Unsigned32();
                break;
            case 6:
            case 7:
            case 8:
            case 9:
                choice = new Unsigned64();
                break;
            default:
                return false;
            }

            break;
        // another TL-Field follows
        // this is only possible if an octetstring was sent
        case TL_FIELD:
            choice = new OctetString();
            break;
        default:
            return false;
        }

        // push back the TL-field of the choice-object
        ispushback.unread(tlFieldChoice);
        if (!choice.decode(is2)) {
            return false;
        }

        isSelected = true;
        return true;
    }

    public ASNObject getChoice() {
        return choice;
    }

    public String getDatatype() {
        return choice.getClass().getName();
    }

}
