/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
package org.openmuc.jsml.structures;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

public class Integer16 extends ASNObject {

    protected short val;

    public Integer16() {
    }

    public Integer16(short i) {
        val = i;
        isSelected = true;
    }

    public short getVal() {
        return val;
    }

    @Override
    public void encode(DataOutputStream os) throws IOException {
        if (isOptional && !isSelected) {
            os.writeByte(0x01);
            return;
        }
        os.writeByte(0x53);
        os.writeShort(val);
    }

    @Override
    public boolean decode(DataInputStream is) throws IOException {
        int typeLengthField = is.readByte();
        if (isOptional && (typeLengthField == 0x01)) {
            isSelected = false;
            return true;
        }
        if ((typeLengthField & 0x50) != 0x50) {
            return false;
        }
        // get length of unsigned with tl-field and subtract the tl-field
        int length = (typeLengthField & 0x0F) - 1;
        val = 0;

        for (int j = length - 1; j >= 0; j--) {
            val |= (is.readByte() & 0xff) << (8 * j);
        }

        if (((val >> (8 * (length - 1))) & 0x80) == 0x80) {
            for (int i = 2; i > length; i--) {
                val |= (0xFF) << (8 * (i - 1));
            }
        }
        isSelected = true;
        return true;
    }

    @Override
    public String toString() {
        return String.valueOf(val);
    }
}
