/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
package org.openmuc.jsml.structures.requests;

import org.openmuc.jsml.structures.ASNObject;
import org.openmuc.jsml.structures.ListOfSmlObjReqEntry;
import org.openmuc.jsml.structures.OctetString;
import org.openmuc.jsml.structures.Sequence;
import org.openmuc.jsml.structures.SmlBoolean;
import org.openmuc.jsml.structures.SmlTime;
import org.openmuc.jsml.structures.SmlTree;
import org.openmuc.jsml.structures.SmlTreePath;

public class SmlGetProfilePackReq extends Sequence {

    protected OctetString serverId; // OPTIONAL,
    protected OctetString username; // OPTIONAL,
    protected OctetString password; // OPTIONAL,
    protected SmlBoolean withRawdata; // OPTIONAL,
    protected SmlTime beginTime; // OPTIONAL,
    protected SmlTime endTime; // OPTIONAL,
    protected SmlTreePath parameterTreePath;
    protected ListOfSmlObjReqEntry objectList; // OPTIONAL,
    protected SmlTree dasDetails; // OPTIONAL

    public SmlGetProfilePackReq() {
    }

    public SmlGetProfilePackReq(OctetString serverId, OctetString username, OctetString password,
            SmlBoolean withRawdata, SmlTime beginTime, SmlTime endTime, SmlTreePath parameterTreePath,
            ListOfSmlObjReqEntry objectList, SmlTree dasDetails) {

        if (parameterTreePath == null) {
            throw new IllegalArgumentException(
                    "SML_GetProfilePackReq: parameterTreePath is not optional and must not be null!");
        }

        this.serverId = serverId;
        this.username = username;
        this.password = password;
        this.withRawdata = withRawdata;
        this.beginTime = beginTime;
        this.endTime = endTime;
        this.parameterTreePath = parameterTreePath;
        this.objectList = objectList;
        this.dasDetails = dasDetails;

        if (this.serverId == null) {
            this.serverId = new OctetString();
        }
        if (this.username == null) {
            this.username = new OctetString();
        }
        if (this.password == null) {
            this.password = new OctetString();
        }
        if (this.withRawdata == null) {
            this.withRawdata = new SmlBoolean();
        }
        if (this.beginTime == null) {
            this.beginTime = new SmlTime();
        }
        if (this.endTime == null) {
            this.endTime = new SmlTime();
        }
        if (this.objectList == null) {
            this.objectList = new ListOfSmlObjReqEntry();
        }
        if (this.dasDetails == null) {
            this.dasDetails = new SmlTree();
        }

        setOptionalAndSeq();
        isSelected = true;
    }

    public OctetString getServerId() {
        return serverId;
    }

    public OctetString getUsername() {
        return username;
    }

    public OctetString getPassword() {
        return password;
    }

    public SmlBoolean getWithRawdata() {
        return withRawdata;
    }

    public SmlTime getBeginTime() {
        return beginTime;
    }

    public SmlTime getEndTime() {
        return endTime;
    }

    public SmlTreePath getParameterTreePath() {
        return parameterTreePath;
    }

    public ListOfSmlObjReqEntry getObjectList() {
        return objectList;
    }

    public SmlTree getDasDetails() {
        return dasDetails;
    }

    public void setOptionalAndSeq() {

        serverId.setOptional();
        username.setOptional();
        password.setOptional();
        withRawdata.setOptional();
        beginTime.setOptional();
        endTime.setOptional();
        objectList.setOptional();
        dasDetails.setOptional();

        seqArray = new ASNObject[] { serverId, username, password, withRawdata, beginTime, endTime, parameterTreePath,
                objectList, dasDetails };
    }

    @Override
    protected void createElements() {
        serverId = new OctetString();
        username = new OctetString();
        password = new OctetString();
        withRawdata = new SmlBoolean();
        beginTime = new SmlTime();
        endTime = new SmlTime();
        parameterTreePath = new SmlTreePath();
        objectList = new ListOfSmlObjReqEntry();
        dasDetails = new SmlTree();

        setOptionalAndSeq();
    }

}
