/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
package org.openmuc.jsml.transport;

import java.net.Socket;

/*
 * The class extends Thread and handles SML connections. Once a connection has been initiated
 * it gives the connection in form of the Connection class to the ConnectionListener and the thread is closed.
 */
public class ConnectionHandler extends Thread {

    private final Socket socket;
    private final ServerThread serverThread;

    ConnectionHandler(Socket socket, ServerThread serverThread) {
        this.socket = socket;
        this.serverThread = serverThread;
    }

    @Override
    public void run() {
        try {
            TConnection tConnection;
            try {
                tConnection = new TConnection(socket, serverThread.messageTimeout, serverThread.messageFragmentTimeout);
            } catch (Exception e) {
                System.err.println("Exception occured when someone tried to connect.");
                return;
            }

            if (serverThread.isAlive() == true) {
                serverThread.connectionIndication(tConnection);
            }

            if (tConnection != null) {
                tConnection.close();
            }

        } finally {
            serverThread.removeHandler(this);
        }
    }
}

// public class ConnectionHandler extends Thread {
//
// private Socket socket;
// private ServerThread serverThread;
//
// ConnectionHandler(Socket socket, ServerThread serverThread) {
// this.socket = socket;
// this.serverThread = serverThread;
// }
//
// @Override
// public void run() {
// try {
// TConnection tConnection = null;
// try {
// tConnection = new TConnection(socket, serverThread.maxTPDUSizeParam,
// serverThread.messageTimeout,
// serverThread.messageFragmentTimeout);
// } catch (Throwable e) {
// System.err.println("Exception occured when someone tried to connect.");
// return;
// }
// try {
// tConnection.listenForCR();
// } catch (Throwable e) {
// System.err
// .println("Exception occured when someone tried to connect. Server was listening for ISO Transport CR packet.");
// tConnection.close();
// return;
// }
// if (serverThread.isAlive() == true) {
// serverThread.connectionIndication(tConnection);
// }
//
// if (tConnection != null) {
// tConnection.close();
// }
//
// } finally {
// serverThread.removeHandler(this);
// }
// }
// }
